@@ -15,7 +15,8 @@ class QString;
 
 class QTextBrowser;
 
-namespace KABPrinting {
+namespace KABPrinting
+{
 /**
   This defines a simple widget to display print progress
   information. It is provided to all print styles during a print
@@ -27,7 +28,7 @@ class PrintProgress : public QWidget
 
 public:
     explicit PrintProgress(QWidget *parent);
-    ~PrintProgress();
+    ~PrintProgress() override;
 
     /**
       Add a message to the message log. Give the user something to admire :-)
